{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/bio-client:latest"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1,
                    "ramMin": 1000,
                    "ramMax": 1000,
                    "tmpdirMin": 1,
                    "tmpdirMax": 1,
                    "outdirMin": 1,
                    "outdirMax": 1
                }
            ],
            "inputs": [
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/config-file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config-file",
                        "position": 0
                    }
                },
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/upload",
                    "type": "string",
                    "default": "upload",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/upload-bucket",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--upload-bucket",
                        "position": 2
                    }
                },
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/upload-key",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--upload_key",
                        "position": 3
                    }
                },
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "position": 99
                    }
                }
            ],
            "baseCommand": [
                "/usr/local/bin/bio_client.py"
            ],
            "id": "#bioclient_upload_pull_uuid.cwl",
            "outputs": [
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_upload.json"
                    }
                },
                {
                    "id": "#bioclient_upload_pull_uuid.cwl/uuid",
                    "type": "string",
                    "outputBinding": {
                        "glob": "*_upload.json",
                        "loadContents": true,
                        "outputEval": "${\n   var data = JSON.parse(self[0].contents);\n   return(data[\"did\"]);\n }\n"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/bioclient_config"
                },
                {
                    "type": "File",
                    "id": "#main/htseq_counts_file"
                },
                {
                    "type": "File",
                    "id": "#main/htseq_fpkm_file"
                },
                {
                    "type": "File",
                    "id": "#main/htseq_fpkm_uq_file"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#main/upload_bucket"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputSource": "#main/upload_counts/uuid",
                    "id": "#main/counts_uuid"
                },
                {
                    "type": "string",
                    "outputSource": "#main/upload_fpkm_uq/uuid",
                    "id": "#main/fpkm_uq_uuid"
                },
                {
                    "type": "string",
                    "outputSource": "#main/upload_fpkm/uuid",
                    "id": "#main/fpkm_uuid"
                }
            ],
            "steps": [
                {
                    "run": "#bioclient_upload_pull_uuid.cwl",
                    "in": [
                        {
                            "source": "#main/bioclient_config",
                            "id": "#main/upload_counts/config-file"
                        },
                        {
                            "source": "#main/htseq_counts_file",
                            "id": "#main/upload_counts/input"
                        },
                        {
                            "source": "#main/upload_bucket",
                            "id": "#main/upload_counts/upload-bucket"
                        },
                        {
                            "source": [
                                "#main/job_uuid",
                                "#main/htseq_counts_file"
                            ],
                            "valueFrom": "$(self[0] + '/' + self[1].basename)",
                            "id": "#main/upload_counts/upload-key"
                        }
                    ],
                    "out": [
                        "#main/upload_counts/output",
                        "#main/upload_counts/uuid"
                    ],
                    "id": "#main/upload_counts"
                },
                {
                    "run": "#bioclient_upload_pull_uuid.cwl",
                    "in": [
                        {
                            "source": "#main/bioclient_config",
                            "id": "#main/upload_fpkm/config-file"
                        },
                        {
                            "source": "#main/htseq_fpkm_file",
                            "id": "#main/upload_fpkm/input"
                        },
                        {
                            "source": "#main/upload_bucket",
                            "id": "#main/upload_fpkm/upload-bucket"
                        },
                        {
                            "source": [
                                "#main/job_uuid",
                                "#main/htseq_fpkm_file"
                            ],
                            "valueFrom": "$(self[0] + '/' + self[1].basename)",
                            "id": "#main/upload_fpkm/upload-key"
                        }
                    ],
                    "out": [
                        "#main/upload_fpkm/output",
                        "#main/upload_fpkm/uuid"
                    ],
                    "id": "#main/upload_fpkm"
                },
                {
                    "run": "#bioclient_upload_pull_uuid.cwl",
                    "in": [
                        {
                            "source": "#main/bioclient_config",
                            "id": "#main/upload_fpkm_uq/config-file"
                        },
                        {
                            "source": "#main/htseq_fpkm_uq_file",
                            "id": "#main/upload_fpkm_uq/input"
                        },
                        {
                            "source": "#main/upload_bucket",
                            "id": "#main/upload_fpkm_uq/upload-bucket"
                        },
                        {
                            "source": [
                                "#main/job_uuid",
                                "#main/htseq_fpkm_uq_file"
                            ],
                            "valueFrom": "$(self[0] + '/' + self[1].basename)",
                            "id": "#main/upload_fpkm_uq/upload-key"
                        }
                    ],
                    "out": [
                        "#main/upload_fpkm_uq/output",
                        "#main/upload_fpkm_uq/uuid"
                    ],
                    "id": "#main/upload_fpkm_uq"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
